@@ -12,6 +12,6 @@ pub use self::func_state::FuncTranslationState;
 pub use self::func_translator::FuncTranslator;
 pub use self::translation_utils::{
     get_vmctx_value_label, irlibcall_to_libcall, irreloc_to_relocationkind,
-    signature_to_cranelift_ir, transform_jump_table, type_to_irtype,
+    signature_to_cranelift_ir, type_to_irtype,
 };
 pub(crate) use self::unwind::{compiled_function_unwind_info, CraneliftUnwindInfo};
