@@ -73,6 +73,11 @@ impl BuiltinPackageLoader {
         ))
     }
 
+    /// Insert a container into the in-memory hash.
+    pub fn insert_cached(&self, hash: WebcHash, container: &Container) {
+        self.in_memory.save(container, hash);
+    }
+
     #[tracing::instrument(level = "debug", skip_all, fields(pkg.hash=%hash))]
     async fn get_cached(&self, hash: &WebcHash) -> Result<Option<Container>, Error> {
         if let Some(cached) = self.in_memory.lookup(hash) {
@@ -239,7 +244,11 @@ impl FileSystemCache {
     async fn lookup(&self, hash: &WebcHash) -> Result<Option<Container>, Error> {
         let path = self.path(hash);
 
-        match Container::from_disk(&path) {
+        #[cfg(target_arch = "wasm32")]
+        let container = Container::from_disk(&path);
+        #[cfg(not(target_arch = "wasm32"))]
+        let container = tokio::task::block_in_place(|| Container::from_disk(&path));
+        match container {
             Ok(c) => Ok(Some(c)),
             Err(ContainerError::Open { error, .. })
             | Err(ContainerError::Read { error, .. })
@@ -371,8 +380,7 @@ mod tests {
         }
     }
 
-    #[tokio::test]
-    async fn cache_misses_will_trigger_a_download() {
+    async fn cache_misses_will_trigger_a_download_internal() {
         let temp = TempDir::new().unwrap();
         let client = Arc::new(DummyClient::with_responses([HttpResponse {
             body: Some(PYTHON.to_vec()),
@@ -421,4 +429,16 @@ mod tests {
         let in_memory = loader.in_memory.0.read().unwrap();
         assert!(in_memory.contains_key(&summary.dist.webc_sha256));
     }
+
+    #[cfg(not(target_arch = "wasm32"))]
+    #[tokio::test(flavor = "multi_thread")]
+    async fn cache_misses_will_trigger_a_download() {
+        cache_misses_will_trigger_a_download_internal().await
+    }
+
+    #[cfg(target_arch = "wasm32")]
+    #[tokio::test()]
+    async fn cache_misses_will_trigger_a_download() {
+        cache_misses_will_trigger_a_download_internal().await
+    }
 }
